@@ -46,8 +46,8 @@
 #include <tqfile.h>
 
 #include <dcopclient.h>
-#include <kactioncollection.h>
-#include <kstartupinfo.h>
+#include <tdeactioncollection.h>
+#include <tdestartupinfo.h>
 
 
 namespace Amarok
@@ -307,19 +307,19 @@ namespace Amarok
 
     void DcopPlayerHandler::enableRandomMode( bool enable )
     {
-        static_cast<KSelectAction*>(Amarok::actionCollection()->action( "random_mode" ))
+        static_cast<TDESelectAction*>(Amarok::actionCollection()->action( "random_mode" ))
             ->setCurrentItem( enable ? AmarokConfig::EnumRandomMode::Tracks : AmarokConfig::EnumRandomMode::Off );
     }
 
     void DcopPlayerHandler::enableRepeatPlaylist( bool enable )
     {
-        static_cast<KSelectAction*>( Amarok::actionCollection()->action( "repeat" ) )
+        static_cast<TDESelectAction*>( Amarok::actionCollection()->action( "repeat" ) )
                ->setCurrentItem( enable ? AmarokConfig::EnumRepeat::Playlist : AmarokConfig::EnumRepeat::Off );
     }
 
      void DcopPlayerHandler::enableRepeatTrack( bool enable)
     {
-        static_cast<KSelectAction*>( Amarok::actionCollection()->action( "repeat" ) )
+        static_cast<TDESelectAction*>( Amarok::actionCollection()->action( "repeat" ) )
                ->setCurrentItem( enable ? AmarokConfig::EnumRepeat::Track : AmarokConfig::EnumRepeat::Off );
     }
 
@@ -523,7 +523,7 @@ namespace Amarok
         kapp->setStartupId( args.first().local8Bit() );
 #ifdef TQ_WS_X11
         // currently X11 only
-        KStartupInfo::appStarted();
+        TDEStartupInfo::appStarted();
 #endif
         args.pop_front();
 
@@ -532,14 +532,14 @@ namespace Amarok
 
         TQStringList::ConstIterator it = args.constBegin();
         for( int i = 1; i < argc; ++i, ++it ) {
-            argv[i] = qstrdup( (*it).local8Bit() );
+            argv[i] = tqstrdup( (*it).local8Bit() );
             debug() << "Extracted: " << argv[i] << endl;
         }
 
         // required, loader doesn't add it
-        argv[0] = qstrdup( "amarokapp" );
+        argv[0] = tqstrdup( "amarokapp" );
 
-        // re-initialize KCmdLineArgs with the new arguments
+        // re-initialize TDECmdLineArgs with the new arguments
         App::initCliArgs( argc, argv );
         App::handleCliArgs();
 
@@ -937,7 +937,7 @@ namespace Amarok
     TQString DcopScriptHandler::readConfig(const TQString& key)
     {
         TQString cleanKey = key;
-        KConfigSkeletonItem* configItem = AmarokConfig::self()->findItem(cleanKey.remove(' '));
+        TDEConfigSkeletonItem* configItem = AmarokConfig::self()->findItem(cleanKey.remove(' '));
         if (configItem)
             return configItem->property().toString();
         else
@@ -947,7 +947,7 @@ namespace Amarok
     TQStringList DcopScriptHandler::readListConfig(const TQString& key)
     {
         TQString cleanKey = key;
-        KConfigSkeletonItem* configItem = AmarokConfig::self()->findItem(cleanKey.remove(' '));
+        TDEConfigSkeletonItem* configItem = AmarokConfig::self()->findItem(cleanKey.remove(' '));
         TQStringList stringList;
         if(configItem)
         {
