@@ -41,7 +41,7 @@ typedef TQMap<TQString, TQString> AttributeMap;
 
 class CollectionScanner : public TDEApplication
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
