@@ -12,6 +12,9 @@
 #include <tqobject.h>
 #include <sys/time.h>
 
+#include "amarok_export.h"
+
+
 class TQApplication;
 extern TQApplication *tqApp; ///@see Debug::Indent
 
@@ -46,7 +49,7 @@ extern TQApplication *tqApp; ///@see Debug::Indent
  * @see ListStream
  */
 
-namespace Debug
+namespace Debug LIBAMAROK_EXPORT
 {
     extern TQMutex mutex; // defined in app.cpp
 
@@ -133,7 +136,7 @@ using Debug::DebugStream;
 #define AMAROK_DEPRECATED warning() << "DEPRECATED: " << __PRETTY_FUNCTION__ << endl;
 
 
-namespace Debug
+namespace Debug LIBAMAROK_EXPORT
 {
     /**
      * @class Debug::Block
@@ -230,7 +233,7 @@ namespace Debug
 
 #include <tqvariant.h>
 
-namespace Debug
+namespace Debug LIBAMAROK_EXPORT
 {
     /**
      * @class Debug::List
