@@ -116,11 +116,6 @@ void HXUnixDebugBreak();
 #include <stdlib.h>
 #endif
 
-#ifdef _SYMBIAN
-# include <unistd.h>
-# define _MAX_PATH MAXPATHLEN
-#endif
-
 #ifdef _OPENWAVE
 #ifndef _MAX_PATH
 #define _MAX_PATH 256
@@ -136,8 +131,6 @@ void HXUnixDebugBreak();
 #  define MAX_TRACE_OUTPUT  255
 # elif _WIN16
 #  define MAX_TRACE_OUTPUT  255
-# elif _SYMBIAN
-#  define MAX_TRACE_OUTPUT  255
 # else
 #  define MAX_TRACE_OUTPUT  (_MAX_PATH*2 + 20)
 # endif
@@ -254,12 +247,6 @@ HXBOOL STDMETHODCALLTYPE HXIsValidString(const char* lpsz, int nLength);
 #else
 void HXDebugBreak();
 #endif
-#elif defined(_SYMBIAN)
-#if defined(__WINS__)
-#define HXDebugBreak() _asm { int 3 }
-#else
-void HXDebugBreak();
-#endif //_SYMBIAN
 #elif  defined(_UNIX)
 void HXDebugBreak();
 #elif defined(_VXWORKS)
@@ -300,8 +287,6 @@ do {						\
 # define HXAbort() 	abort()
 #elif defined(WIN32_PLATFORM_PSPC)
 # define HXAbort()   exit(1)
-#elif defined(_SYMBIAN)
-# define HXAbort() exit(1)
 #elif defined(_OPENWAVE)
 // XXXSAB is this right??
 # define HXAbort() exit(1)
