@@ -1224,95 +1224,6 @@ extern HXAtomic g_AtomicOps; //in common/util/atomicops.cpp
 
 
 
-/***********************************************************************
- * SYMBIAN
- *
- * Implementation Notes:
- *
- * Note: This is an imcompletely-defined platform, be aware that
- * not all standard HXAtomic operators are defined!
- *
- */
-#elif defined(_SYMBIAN)
-
-/* Increment by 1 and return new value */
-inline INT32
-HXAtomicIncRetINT32(INT32* pNum)
-{
-    return User::LockedInc(*((TInt*)pNum)) + 1;
-}
-
-/* Decrement by 1 and return new value */
-inline INT32
-HXAtomicDecRetINT32(INT32* pNum)
-{
-    return User::LockedDec(*((TInt*)pNum)) - 1;
-}
-
-/* Increment by 1 and return new value */
-inline UINT32
-HXAtomicIncRetUINT32(UINT32* pNum)
-{
-    return ((UINT32)User::LockedInc(*((TInt*)pNum))) + 1;
-}
-
-/* Decrement by 1 and return new value */
-inline UINT32
-HXAtomicDecRetUINT32(UINT32* pNum)
-{
-    return ((UINT32)User::LockedDec(*((TInt*)pNum))) - 1;
-}
-
-#define HXAtomicIncINT32(p)    HXAtomicIncRetINT32((p))
-#define HXAtomicDecINT32(p)    HXAtomicDecRetINT32((p))
-#define HXAtomicIncUINT32(p)   HXAtomicIncRetUINT32((p))
-#define HXAtomicDecUINT32(p)   HXAtomicDecRetUINT32((p))
-
-#if 0
-
-/* 
- * Add and subtract operations are not implemented
- * at this time because there isn't an easy way to
- * do it using the facilities provided by Symbian.
- * Assembly will likely be needed.
- */
-
-/* Add n and return new value */
-inline INT32
-HXAtomicAddRetINT32(INT32* pNum, INT32 n)
-{
-
-}
-
-/* Subtract n and return new value */
-inline INT32
-HXAtomicSubRetINT32(INT32* pNum, INT32 n)
-{
-
-}
-
-/* Add n and return new value */
-inline UINT32
-HXAtomicAddRetUINT32(UINT32* pNum, UINT32 n)
-{
-
-}
-
-/* Subtract n and return new value */
-inline UINT32
-HXAtomicSubRetUINT32(UINT32* pNum, UINT32 n)
-{
-
-}
-
-#define HXAtomicAddINT32(p,n)  HXAtomicAddRetINT32((p),(n))
-#define HXAtomicSubINT32(p,n)  HXAtomicSubRetINT32((p),(n))
-
-#define HXAtomicAddUINT32(p,n) HXAtomicAddRetUINT32((p),(n))
-#define HXAtomicSubUINT32(p,n) HXAtomicSubRetUINT32((p),(n))
-
-#endif
-
 /***********************************************************************
  * Linux / ARM (gcc)
  *
