@@ -1112,8 +1112,8 @@ MtpMediaDevice::openDevice( bool silent )
     }
 
     connect(
-        m_view, TQT_SIGNAL( itemRenamed( TQListViewItem*, const TQString&, int ) ),
-        this,   TQT_SLOT( playlistRenamed( TQListViewItem*, const TQString&, int ) )
+        m_view, TQ_SIGNAL( itemRenamed( TQListViewItem*, const TQString&, int ) ),
+        this,   TQ_SLOT( playlistRenamed( TQListViewItem*, const TQString&, int ) )
     );
 
     TQString modelname = TQString( LIBMTP_Get_Modelname( m_device ) );
