@@ -420,7 +420,7 @@ MetaBundle::init( TagLib::AudioProperties *ap )
     if ( ap )
     {
         m_bitrate    = ap->bitrate();
-        m_length     = ap->length();
+        m_length     = ap->lengthInSeconds();
         m_sampleRate = ap->sampleRate();
     }
     else
@@ -1338,7 +1338,7 @@ MetaBundle::setExtendedTag( TagLib::File *file, int tag, const TQString value )
         if ( oggFile && oggFile->tag() )
         {
             value.isEmpty() ?
-                oggFile->tag()->removeField( id ):
+                oggFile->tag()->removeFields( id ):
                 oggFile->tag()->addField( id, QStringToTString( value ), true );
         }
     }
@@ -1356,7 +1356,7 @@ MetaBundle::setExtendedTag( TagLib::File *file, int tag, const TQString value )
         if ( flacFile && flacFile->xiphComment() )
         {
             value.isEmpty() ?
-            flacFile->xiphComment()->removeField( id ):
+            flacFile->xiphComment()->removeFields( id ):
             flacFile->xiphComment()->addField( id, QStringToTString( value ), true );
         }
     }
