@@ -60,13 +60,13 @@ OSDWidget::OSDWidget( TQWidget *parent, const char *name )
         , m_rating( 0 )
         , m_volume( false )
 {
-    setFocusPolicy( TQ_NoFocus );
+    setFocusPolicy( TQWidget::NoFocus );
     setBackgroundMode( NoBackground );
     unsetColors();
 
-    connect( m_timer, TQT_SIGNAL(timeout()), TQT_SLOT(hide()) );
-    connect( CollectionDB::instance(), TQT_SIGNAL( ratingChanged( const TQString&, int ) ),
-             this, TQT_SLOT( ratingChanged( const TQString&, int ) ) );
+    connect( m_timer, TQ_SIGNAL(timeout()), TQ_SLOT(hide()) );
+    connect( CollectionDB::instance(), TQ_SIGNAL( ratingChanged( const TQString&, int ) ),
+             this, TQ_SLOT( ratingChanged( const TQString&, int ) ) );
 
     //or crashes, KWin bug I think, crashes in TQWidget::icon()
     kapp->setTopWidget( this );
@@ -225,7 +225,7 @@ OSDWidget::determineMetrics( const uint M )
         m_scaledCover = m_cover.smoothScale(
                 TQMIN( availableWidth, m_cover.width() ),
                 TQMIN( rect.height(), m_cover.height() ),
-                TQ_ScaleMin ); //this will force us to be with our bounds
+                TQImage::ScaleMin ); //this will force us to be with our bounds
 
         int shadowWidth = 0;
         if( m_drawShadow && !m_scaledCover.hasAlpha() &&
@@ -624,7 +624,7 @@ void OSDPreviewWidget::mousePressEvent( TQMouseEvent *event )
 {
     m_dragOffset = event->pos();
 
-    if( event->button() == Qt::LeftButton && !m_dragging ) {
+    if( event->button() == TQt::LeftButton && !m_dragging ) {
         grabMouse( KCursor::sizeAllCursor() );
         m_dragging = true;
     }
@@ -707,10 +707,10 @@ void OSDPreviewWidget::mouseMoveEvent( TQMouseEvent *e )
 
 Amarok::OSD::OSD(): OSDWidget( 0 )
 {
-    connect( CollectionDB::instance(), TQT_SIGNAL( coverChanged( const TQString&, const TQString& ) ),
-             this,                   TQT_SLOT( slotCoverChanged( const TQString&, const TQString& ) ) );
-    connect( CollectionDB::instance(), TQT_SIGNAL( imageFetched( const TQString& ) ),
-             this,                   TQT_SLOT( slotImageChanged( const TQString& ) ) );
+    connect( CollectionDB::instance(), TQ_SIGNAL( coverChanged( const TQString&, const TQString& ) ),
+             this,                   TQ_SLOT( slotCoverChanged( const TQString&, const TQString& ) ) );
+    connect( CollectionDB::instance(), TQ_SIGNAL( imageFetched( const TQString& ) ),
+             this,                   TQ_SLOT( slotImageChanged( const TQString& ) ) );
 }
 
 void
