@@ -102,13 +102,13 @@ PodcastSettingsDialog::init()
         enableButtonOK( false );
 
          // Connects for modification check
-        connect( m_ps->m_purgeCountSpinBox->child( "qt_spinbox_edit" ),  TQT_SIGNAL(textChanged( const TQString& )), TQT_SLOT(checkModified()) );
-        connect( m_ps->m_saveLocation,   TQT_SIGNAL(textChanged( const TQString& )), TQT_SLOT(checkModified()) );
-        connect( m_ps->m_autoFetchCheck, TQT_SIGNAL(clicked()),                     TQT_SLOT(checkModified()) );
-        connect( m_ps->m_streamRadio,    TQT_SIGNAL(clicked()),                     TQT_SLOT(checkModified()) );
-        connect( m_ps->m_addToMediaDeviceCheck, TQT_SIGNAL(clicked()),              TQT_SLOT(checkModified()) );
-        connect( m_ps->m_downloadRadio,  TQT_SIGNAL(clicked()),                     TQT_SLOT(checkModified()) );
-        connect( m_ps->m_purgeCheck,     TQT_SIGNAL(clicked()),                     TQT_SLOT(checkModified()) );
+        connect( m_ps->m_purgeCountSpinBox->child( "qt_spinbox_edit" ),  TQ_SIGNAL(textChanged( const TQString& )), TQ_SLOT(checkModified()) );
+        connect( m_ps->m_saveLocation,   TQ_SIGNAL(textChanged( const TQString& )), TQ_SLOT(checkModified()) );
+        connect( m_ps->m_autoFetchCheck, TQ_SIGNAL(clicked()),                     TQ_SLOT(checkModified()) );
+        connect( m_ps->m_streamRadio,    TQ_SIGNAL(clicked()),                     TQ_SLOT(checkModified()) );
+        connect( m_ps->m_addToMediaDeviceCheck, TQ_SIGNAL(clicked()),              TQ_SLOT(checkModified()) );
+        connect( m_ps->m_downloadRadio,  TQ_SIGNAL(clicked()),                     TQ_SLOT(checkModified()) );
+        connect( m_ps->m_purgeCheck,     TQ_SIGNAL(clicked()),                     TQ_SLOT(checkModified()) );
 }
 
 bool
