@@ -64,7 +64,7 @@ namespace SingleShotPool
         TQTimer *timer = static_cast<TQTimer*>( receiver->child( slot ) );
         if( !timer ) {
             timer = new TQTimer( receiver, slot );
-            receiver->connect( timer, TQT_SIGNAL(timeout()), slot );
+            receiver->connect( timer, TQ_SIGNAL(timeout()), slot );
         }
 
         timer->start( timeout, true );
@@ -115,15 +115,15 @@ StatusBar::StatusBar( TQWidget *parent, const char *name )
 
     shortLongButton->setIconSet( SmallIconSet( "edit_add" ) );
     TQToolTip::add( shortLongButton, i18n( "Show details" ) );
-    connect( shortLongButton, TQT_SIGNAL(clicked()), TQT_SLOT(showShortLongDetails()) );
+    connect( shortLongButton, TQ_SIGNAL(clicked()), TQ_SLOT(showShortLongDetails()) );
 
     b1->setIconSet( SmallIconSet( "cancel" ) );
     b2->setIconSet( SmallIconSet( "2uparrow") );
     b2->setToggleButton( true );
     TQToolTip::add( b1, i18n( "Abort all background-operations" ) );
     TQToolTip::add( b2, i18n( "Show progress detail" ) );
-    connect( b1, TQT_SIGNAL(clicked()), TQT_SLOT(abortAllProgressOperations()) );
-    connect( b2, TQT_SIGNAL(toggled( bool )), TQT_SLOT(toggleProgressWindow( bool )) );
+    connect( b1, TQ_SIGNAL(clicked()), TQ_SLOT(abortAllProgressOperations()) );
+    connect( b2, TQ_SIGNAL(toggled( bool )), TQ_SLOT(toggleProgressWindow( bool )) );
 
     m_popupProgress = new OverlayWidget( this, mainProgressBarBox, "popupProgress" );
     m_popupProgress->setMargin( 1 );
@@ -151,20 +151,20 @@ StatusBar::polish()
     TQObjectList *list = queryList( "TQWidget", 0, false, false );
 
     for( TQObject * o = list->first(); o; o = list->next() ) {
-        int _h = TQT_TQWIDGET( o ) ->minimumSizeHint().height();
+        int _h = static_cast<TQWidget*>( o ) ->minimumSizeHint().height();
         if ( _h > h )
             h = _h;
 
-//         debug() << o->className() << ", " << o->name() << ": " << _h << ": " << TQT_TQWIDGET(o)->minimumHeight() << endl;
+//         debug() << o->className() << ", " << o->name() << ": " << _h << ": " << static_cast<TQWidget*>(o)->minimumHeight() << endl;
 
         if ( o->inherits( "TQLabel" ) )
-            static_cast<TQLabel*>(TQT_TQWIDGET(o))->setIndent( 4 );
+            static_cast<TQLabel*>(o)->setIndent( 4 );
     }
 
     h -= 4; // it's too big usually
 
     for ( TQObject * o = list->first(); o; o = list->next() )
-        TQT_TQWIDGET(o)->setFixedHeight( h );
+      static_cast<TQWidget*>(o)->setFixedHeight( h );
 
     delete list;
 }
@@ -176,12 +176,12 @@ StatusBar::paintEvent( TQPaintEvent* )
     TQPainter p( this );
 
     for( TQObject * o = list->first(); o; o = list->next() ) {
-        TQWidget *w = TQT_TQWIDGET( o );
+        TQWidget *w = static_cast<TQWidget*>( o );
 
         if ( !w->isVisible() )
             continue;
 
-        style().tqdrawPrimitive(
+        style().drawPrimitive(
                 TQStyle::PE_StatusBarSection,
                 &p,
                 TQRect( w->x() - 1, w->y() - 1, w->width() + 2, w->height() + 2 ),
@@ -224,7 +224,7 @@ StatusBar::shortMessage( const TQString &text, bool longShort )
     m_mainTextLabel->setText( text );
     m_mainTextLabel->setPalette( TQToolTip::palette() );
 
-    SingleShotPool::startTimer( longShort ? 8000 : 5000, TQT_TQOBJECT(this), TQT_SLOT(resetMainText()) );
+    SingleShotPool::startTimer( longShort ? 8000 : 5000, this, TQ_SLOT(resetMainText()) );
 
     writeLogFile( text );
 }
@@ -236,7 +236,7 @@ StatusBar::resetMainText()
 //         debug() << sender()->name() << endl;
 
     // don't reset if we are showing a shortMessage
-    if( SingleShotPool::isActive( TQT_TQOBJECT(this), TQT_SLOT(resetMainText()) ) )
+    if( SingleShotPool::isActive( this, TQ_SLOT(resetMainText()) ) )
         return;
 
     m_mainTextLabel->unsetPalette();
@@ -288,7 +288,7 @@ StatusBar::longMessage( const TQString &text, int type )
 
     PopupMessage *message;
     message = new PopupMessage( this, m_mainTextLabel );
-    connect( message, TQT_SIGNAL(destroyed(TQObject *)), this, TQT_SLOT(popupDeleted(TQObject *)) );
+    connect( message, TQ_SIGNAL(destroyed(TQObject *)), this, TQ_SLOT(popupDeleted(TQObject *)) );
     message->setText( text );
 
     TQString image;
@@ -330,7 +330,7 @@ StatusBar::longMessage( const TQString &text, int type )
 void
 StatusBar::popupDeleted( TQObject *obj )
 {
-    m_messageQueue.remove( TQT_TQWIDGET( obj ) );
+    m_messageQueue.remove( static_cast<TQWidget*>( obj ) );
 }
 
 void
@@ -385,11 +385,11 @@ StatusBar::newProgressOperation( TQObject *owner )
 
     m_popupProgress->reposition();
 
-    connect( owner, TQT_SIGNAL(destroyed( TQObject* )), TQT_SLOT(endProgressOperation( TQObject* )) );
+    connect( owner, TQ_SIGNAL(destroyed( TQObject* )), TQ_SLOT(endProgressOperation( TQObject* )) );
 
     // so we can show the correct progress information
     // after the ProgressBar is setup
-    SingleShotPool::startTimer( 0, TQT_TQOBJECT(this), TQT_SLOT(updateProgressAppearance()) );
+    SingleShotPool::startTimer( 0, this, TQ_SLOT(updateProgressAppearance()) );
 
     progressBox()->show();
     cancelButton()->setEnabled( true );
@@ -407,9 +407,9 @@ StatusBar::newProgressOperation( TDEIO::Job *job )
 
     if(!allDone())
         toggleProgressWindowButton()->show();
-    connect( job, TQT_SIGNAL(result( TDEIO::Job* )), TQT_SLOT(endProgressOperation()) );
-    //TODO connect( job, TQT_SIGNAL(infoMessage( TDEIO::Job *job, const TQString& )), TQT_SLOT() );
-    connect( job, TQT_SIGNAL(percent( TDEIO::Job*, unsigned long )), TQT_SLOT(setProgress( TDEIO::Job*, unsigned long )) );
+    connect( job, TQ_SIGNAL(result( TDEIO::Job* )), TQ_SLOT(endProgressOperation()) );
+    //TODO connect( job, TQ_SIGNAL(infoMessage( TDEIO::Job *job, const TQString& )), TQ_SLOT() );
+    connect( job, TQ_SIGNAL(percent( TDEIO::Job*, unsigned long )), TQ_SLOT(setProgress( TDEIO::Job*, unsigned long )) );
 
     return bar;
 }
@@ -417,7 +417,7 @@ StatusBar::newProgressOperation( TDEIO::Job *job )
 void
 StatusBar::endProgressOperation()
 {
-    TQObject *owner = TQT_TQOBJECT(const_cast<TQObject*>( sender() )); //HACK deconsting it
+    TQObject *owner = const_cast<TQObject*>( sender() );
     TDEIO::Job *job = dynamic_cast<TDEIO::Job*>( owner );
 
     //FIXME doesn't seem to work for TDEIO::DeleteJob, it has it's own error handler and returns no error too
@@ -439,7 +439,7 @@ StatusBar::endProgressOperation( TQObject *owner )
 
     if ( !m_progressMap.contains( owner ) )
     {
-        SingleShotPool::startTimer( 2000, TQT_TQOBJECT(this), TQT_SLOT(hideMainProgressBar()) );
+        SingleShotPool::startTimer( 2000, this, TQ_SLOT(hideMainProgressBar()) );
         return ;
     }
 
@@ -447,7 +447,7 @@ StatusBar::endProgressOperation( TQObject *owner )
 
     if( allDone() && !m_popupProgress->isShown() ) {
         cancelButton()->setEnabled( false );
-        SingleShotPool::startTimer( 2000, TQT_TQOBJECT(this), TQT_SLOT(hideMainProgressBar()) );
+        SingleShotPool::startTimer( 2000, this, TQ_SLOT(hideMainProgressBar()) );
     }
 
     updateTotalProgress();
@@ -471,7 +471,7 @@ StatusBar::toggleProgressWindow( bool show ) //slot
     m_popupProgress->setShown( show );
 
     if( !show )
-        SingleShotPool::startTimer( 2000, TQT_TQOBJECT(this), TQT_SLOT(hideMainProgressBar()) );
+        SingleShotPool::startTimer( 2000, this, TQ_SLOT(hideMainProgressBar()) );
 }
 
 void
