@@ -53,7 +53,7 @@ namespace KDE
      *    statusbar->newProgressOperation( myObject )
      *          .setDescription( i18n("MyProgressOperation") )
      *          .setStatus( i18n("Stage1") )
-     *          .setAbortSlot( myObject, TQT_SLOT(abort()) )
+     *          .setAbortSlot( myObject, TQ_SLOT(abort()) )
      *          .setTotalSteps( 100 );
      *
      * The newProgressOperation function returns a KDE::ProgressBar, which is
@@ -214,10 +214,10 @@ namespace KDE
 
         int  m_logCounter;
 
-        TQWidget *cancelButton() { return TQT_TQWIDGET( child( "cancelButton" ) ); }
-        TQWidget *toggleProgressWindowButton() { return TQT_TQWIDGET( child( "showAllProgressDetails" ) ); }
-        TQWidget *progressBox() { return TQT_TQWIDGET( child( "progressBox" ) ); }
-        TQWidget *shortLongButton() { return TQT_TQWIDGET( child( "shortLongButton" ) ); }
+        TQWidget *cancelButton() { return static_cast<TQWidget*>( child( "cancelButton" ) ); }
+        TQWidget *toggleProgressWindowButton() { return static_cast<TQWidget*>( child( "showAllProgressDetails" ) ); }
+        TQWidget *progressBox() { return static_cast<TQWidget*>( child( "progressBox" ) ); }
+        TQWidget *shortLongButton() { return static_cast<TQWidget*>( child( "shortLongButton" ) ); }
 
         OverlayWidget *m_popupProgress;
         TQProgressBar  *m_mainProgressBar;
